Imagedata packages — imagedata 1.3.0 documentation

# Imagedata packages

## Module Axis

Axis defines a dimension of an images Series.

class `imagedata.axis.` `UniformAxis`(name, start, stop, step=1)

  Define axis by giving start, stop and step (optional). Start, stop and step are given in actual values

  Examples

      >>> ax = UniformAxis('row', 0, 128)

class `imagedata.axis.` `UniformLengthAxis`(name, start, n, step=1)

  Define axis by giving start, length and step (optional). Start and step are given in actual values.

  Examples

      >>> ax = UniformLengthAxis('row', 0, 128)

class `imagedata.axis.` `VariableAxis`(name, values)

  Define axis by giving an array of values. values are actual values.

  Examples

      >>> ax = VariableAxis('time', [0, 1, 4, 9, 11, 13])

## Module cmdline

Add standard command line options.

class `imagedata.cmdline.` `CommaSepAction`(option_strings, dest, nargs=None, **kwargs)

class `imagedata.cmdline.` `DictAction`(option_strings, dest, nargs=None, **kwargs)

class `imagedata.cmdline.` `DtypeAction`(option_strings, dest, nargs=None, **kwargs)

class `imagedata.cmdline.` `InputOrderAction`(option_strings, dest, nargs=None, **kwargs)

class `imagedata.cmdline.` `OutputFormatAction`(option_strings, dest, nargs=None, **kwargs)

class `imagedata.cmdline.` `SortOnAction`(option_strings, dest, nargs=None, **kwargs)

## Module imagedata.header

Image series header

class `imagedata.header.` `Header`

  Image header object.

  Variables

    - input_order –

    - sort_on –

    - input_format –

    - DicomHeaderDict –

    - seriesNumber –

    - seriesDescription –

    - imageType –

    - frameOfReferenceUID –

    - studyInstanceUID –

    - studyID –

    - seriesInstanceUID –

    - SOPClassUID –

    - accessionNumber –

    - patientName –

    - patientID –

    - patientBirthDate –

    - input_sort –

    - sliceLocations –

    - tags –

    - spacing –

    - imagePositions –

    - orientation –

    - transformationMatrix –

    - color –

    - photometricInterpretation –

    - axes –

    - __uid_generator –

    - studyInstanceUID –

    - seriesInstanceUID –

    - frameOfReferenceUID –

    - DicomHeaderDict –

    - tags –

    - axes –

  `new_uid`() → str

    Return the next available UID from the UID generator.

  `set_default_values`(axes)

    Set default values.

`imagedata.header.` `add_geometry`(this, template)

  Add geometry data to this header.

  Parameters

    - this – header or dict

    - template – template header or dict. Can be None.

  Raises

    ValueError – When the template is not a Header or dict.

`imagedata.header.` `add_template`(this, template)

  Add template data to this header. Does not add geometry data.

  Parameters

    - this – header or dict

    - template – template header or dict. Can be None.

  Raises

    ValueError – When the template is not a Header or dict.

## Module imagedata.readdata

Read/Write image files, calling appropriate transport, archive and format plugins

exception `imagedata.readdata.` `NoArchiveError`

exception `imagedata.readdata.` `NoTransportError`

exception `imagedata.readdata.` `UnknownOptionType`

`imagedata.readdata.` `read`(urls, order=None, opts=None)

  Read image data, calling appropriate transport, archive and format plugins

  Parameters

    - urls – list of urls or url to read (list of str, or str)

    - order – determine how to sort the images (default: auto-detect)

    - opts – input options (argparse.Namespace or dict)

  Returns

    tuple of

      - hdr: header instance

      - si[tag,slice,rows,columns]: numpy array

  Raises

    - ValueError – When no sources are given.

    - UnknownOptionType – When opts cannot be made into a dict.

    - FileNotFoundError – When specified URL cannot be opened.

    - imagedata.formats.UnknownInputError – When the input format could not be determined.

    - imagedata.formats.CannotSort – When input data cannot be sorted.

`imagedata.readdata.` `sorted_plugins_dicom_first`(plugins)

  Sort plugins such that any Nifti plugin is used early.

`imagedata.readdata.` `str_to_dtype`(s)

  Convert dtype string to numpy dtype.

`imagedata.readdata.` `write`(si, url, opts=None, formats=None)

  Write image data, calling appropriate format plugins

  Parameters

    - si[tag – Series array

    - slice – Series array

    - rows – Series array

    - columns] – Series array

    - url – output destination url

    - opts – Output options (argparse.Namespace or dict)

    - formats – list of output formats, overriding opts.output_format (list or str)

  Raises

    - UnknownOptionType – When opts cannot be made into a dict.

    - TypeError – List of output format is not list().

    - ValueError – Wrong number of destinations given, or no way to write multidimensional image.

    - imagedata.formats.WriteNotImplemented – Cannot write this image format.